/*
 * DemosceneMusic - AbstractGroup.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.data;

import java.util.Collection;
import java.util.Comparator;

/**
 * Default implementation of a group data container.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class DefaultGroup extends DefaultBase implements Group {

	/** Comparator that sorts groups by name. */
	public static final Comparator<Group> NAME_COMPARATOR = new Comparator<Group>() {

		@Override
		public int compare(Group leftGroup, Group rightGroup) {
			return leftGroup.getName().compareToIgnoreCase(rightGroup.getName());
		}

	};

	/**
	 * Creates a new group data container.
	 *
	 * @param id
	 *            The ID of the group
	 */
	public DefaultGroup(String id) {
		super(id);
	}

	//
	// GROUP METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return getValue("name", String.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Group setName(String name) {
		getValue("name", String.class).set(name);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Collection<Artist> getArtists() {
		return getValue("artists", Collection.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Group setArtists(Collection<Artist> artists) {
		getValue("artists", Collection.class).set(artists);
		return this;
	}

	//
	// OBJECT METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int hashCode() {
		return getId().hashCode();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean equals(Object object) {
		if (!(object instanceof Group)) {
			return false;
		}
		return ((Group) object).getId().equals(getId());
	}

}
